@@ -2,8 +2,6 @@
 This module handles import compatibility issues between Python 2 and
 Python 3.
 """
-# pylint: disable=undefined-variable,import-error,unused-import,no-name-in-module
-
 import sys
 
 _ver = sys.version_info
@@ -12,14 +10,20 @@ _ver = sys.version_info
 is_py2 = _ver[0] == 2
 
 if is_py2:
+    from urllib import quote
+
     from urlparse import urljoin, urlparse
 
     str = unicode
 
     import repr as reprlib
+
+    string_type = basestring
 else:
-    from urllib.parse import urljoin, urlparse
+    from urllib.parse import urljoin, urlparse, quote
 
     str = str
 
     import reprlib
+
+    string_type = str
