@@ -9,7 +9,9 @@ V3_AUTH = u"v3_user_token"
 class BasicAuthProvider(TokenProvider):
     def __init__(self, username, password):
         super(BasicAuthProvider, self).__init__()
-        cred_bytes = base64.b64encode(u"{0}:{1}".format(username, password).encode(u"utf-8"))
+        cred_bytes = base64.b64encode(
+            u"{}:{}".format(username, password).encode(u"utf-8")
+        )
         self._base64_credentials = cred_bytes.decode(u"utf-8")
 
     def get_secret_value(self, force_refresh=False):
@@ -36,7 +38,7 @@ class C42ApiV1TokenProvider(TokenProvider):
     def get_secret_value(self, force_refresh=False):
         uri = u"/api/AuthToken"
         response = self._auth_session.post(uri, data=None)
-        return u"{0}-{1}".format(response[0], response[1])
+        return u"{}-{}".format(response[0], response[1])
 
 
 class C42APITmpAuthProvider(TokenProvider):
@@ -46,7 +48,7 @@ class C42APITmpAuthProvider(TokenProvider):
 
     def get_login_info(self):
         if self._cached_info is None:
-            response = self.get_tmp_auth_token()  # pylint: disable=assignment-from-no-return
+            response = self.get_tmp_auth_token()
             self._cached_info = response
         return self._cached_info
 
@@ -99,18 +101,24 @@ class StorageTokenProviderFactory(object):
         self._device_client = device_client
 
     def create_security_archive_locator(self, plan_uid, destination_guid):
-        return C42APIStorageAuthTokenProvider(self._auth_session, plan_uid, destination_guid)
+        return C42APIStorageAuthTokenProvider(
+            self._auth_session, plan_uid, destination_guid
+        )
 
     def create_backup_archive_locator(self, device_guid, destination_guid=None):
         if destination_guid is None:
-            response = self._device_client.get_by_guid(device_guid, include_backup_usage=True)
+            response = self._device_client.get_by_guid(
+                device_guid, include_backup_usage=True
+            )
             if destination_guid is None:
                 # take the first destination guid we find
                 destination_list = response["backupUsage"]
                 if not destination_list:
                     raise Exception(
-                        u"No destinations found for device guid: {0}".format(device_guid)
+                        u"No destinations found for device guid: {}".format(device_guid)
                     )
                 destination_guid = destination_list[0][u"targetComputerGuid"]
 
-        return C42APILoginTokenProvider(self._auth_session, u"my", device_guid, destination_guid)
+        return C42APILoginTokenProvider(
+            self._auth_session, u"my", device_guid, destination_guid
+        )
