@@ -15,15 +15,15 @@ class DepartingEmployeeClient(BaseClient):
         self._detection_list_user_client = detection_list_user_client
 
     def add(self, user_id, departure_date=None):
-        """Adds a user to the Departing Employees list. Creates a detection list user profile if one
-         didn't already exist.
+        """Adds a user to the Departing Employees list. Creates a detection list user profile if one \
+            didn't already exist.
         `REST Documentation <https://ecm-east.us.code42.com/svc/swagger/index.html?urls.primaryName=v2#/>`__
 
-        Raises a :class:`Py42BadRequestError` when a user already exists in the Departing Employee
-        detection list.
+        Raises a :class:`Py42BadRequestError` when a user already exists in the Departing Employee \
+            detection list.
 
         Args:
-            user_id (str or int): The Code42 userUid of the user you want to add to the departing
+            user_id (str or int): The Code42 userUid of the user you want to add to the departing \
                 employees list.
             departure_date (str, optional): Date in YYYY-MM-DD format. Date is treated as UTC. Defaults to None.
 
@@ -33,7 +33,11 @@ class DepartingEmployeeClient(BaseClient):
         if self._detection_list_user_client.create_if_not_exists(user_id):
             tenant_id = self._user_context.get_current_tenant_id()
 
-            data = {u"tenantId": tenant_id, u"userId": user_id, u"departureDate": departure_date}
+            data = {
+                u"tenantId": tenant_id,
+                u"userId": user_id,
+                u"departureDate": departure_date,
+            }
             uri = self._uri_prefix.format(u"add")
             return self._session.post(uri, data=json.dumps(data))
 
@@ -89,7 +93,9 @@ class DepartingEmployeeClient(BaseClient):
         }
         return self._session.post(uri, data=json.dumps(data))
 
-    def get_all(self, filter_type=u"OPEN", sort_key=u"CREATED_AT", sort_direction=u"DESC"):
+    def get_all(
+        self, filter_type=u"OPEN", sort_key=u"CREATED_AT", sort_direction=u"DESC"
+    ):
         """Gets all Departing Employees.
 
         Args:
@@ -143,5 +149,9 @@ class DepartingEmployeeClient(BaseClient):
         tenant_id = self._user_context.get_current_tenant_id()
 
         uri = self._uri_prefix.format(u"update")
-        data = {u"tenantId": tenant_id, u"userId": user_id, u"departureDate": departure_date}
+        data = {
+            u"tenantId": tenant_id,
+            u"userId": user_id,
+            u"departureDate": departure_date,
+        }
         return self._session.post(uri, data=json.dumps(data))
