@@ -1,5 +1,6 @@
 import json
 
+from py42._internal.compat import quote
 from py42.clients import BaseClient
 from py42.clients.util import get_all_pages
 
@@ -59,7 +60,7 @@ class UserClient(BaseClient):
         Returns:
             :class:`py42.response.Py42Response`: A response containing the user.
         """
-        uri = u"/api/User/{0}".format(user_id)
+        uri = u"/api/User/{}".format(user_id)
         return self._session.get(uri, params=kwargs)
 
     def get_by_uid(self, user_uid, **kwargs):
@@ -72,7 +73,7 @@ class UserClient(BaseClient):
         Returns:
             :class:`py42.response.Py42Response`: A response containing the user.
         """
-        uri = u"/api/User/{0}".format(user_uid)
+        uri = u"/api/User/{}".format(user_uid)
         params = dict(idType=u"uid", **kwargs)
         return self._session.get(uri, params=params)
 
@@ -125,7 +126,9 @@ class UserClient(BaseClient):
 
         return self._session.get(uri, params=params)
 
-    def get_all(self, active=None, email=None, org_uid=None, role_id=None, q=None, **kwargs):
+    def get_all(
+        self, active=None, email=None, org_uid=None, role_id=None, q=None, **kwargs
+    ):
         """Gets all users.
         `REST Documentation <https://console.us.code42.com/apidocviewer/#User-get>`__
 
@@ -156,9 +159,8 @@ class UserClient(BaseClient):
         )
 
     def get_scim_data_by_uid(self, user_uid):
-        """Returns SCIM data such as division, department, and title for
-        a given user.
-        `REST Documentation <https://console.us.code42.com/swagger/#/scim-user-data/ScimUserData_CollatedView>
+        """Returns SCIM data such as division, department, and title for a given user.
+        `REST Documentation <https://console.us.code42.com/swagger/#/scim-user-data/ScimUserData_CollatedView>`__
 
         Args:
             user_uid (str): A Code42 user uid.
@@ -181,7 +183,7 @@ class UserClient(BaseClient):
         Returns:
             :class:`py42.response.Py42Response`
         """
-        uri = u"/api/UserBlock/{0}".format(user_id)
+        uri = u"/api/UserBlock/{}".format(user_id)
         return self._session.put(uri)
 
     def unblock(self, user_id):
@@ -195,7 +197,7 @@ class UserClient(BaseClient):
         Returns:
             :class:`py42.response.Py42Response`
         """
-        uri = u"/api/UserBlock/{0}".format(user_id)
+        uri = u"/api/UserBlock/{}".format(user_id)
         return self._session.delete(uri)
 
     def deactivate(self, user_id, block_user=None):
@@ -210,7 +212,7 @@ class UserClient(BaseClient):
         Returns:
             :class:`py42.response.Py42Response`
         """
-        uri = u"/api/UserDeactivation/{0}".format(user_id)
+        uri = u"/api/UserDeactivation/{}".format(user_id)
         data = {u"blockUser": block_user}
         return self._session.put(uri, data=json.dumps(data))
 
@@ -225,7 +227,7 @@ class UserClient(BaseClient):
         Returns:
             :class:`py42.response.Py42Response`
         """
-        uri = u"/api/UserDeactivation/{0}".format(user_id)
+        uri = u"/api/UserDeactivation/{}".format(user_id)
         params = {u"unblockUser": unblock_user}
         return self._session.delete(uri, params=params)
 
@@ -243,3 +245,59 @@ class UserClient(BaseClient):
         uri = u"/api/UserMoveProcess"
         data = {u"userId": user_id, u"parentOrgId": org_id}
         return self._session.post(uri, data=json.dumps(data))
+
+    def get_available_roles(self):
+        """Report the list of roles that are available for the authenticated user to
+        assign to other users.
+        `V4 REST Documentation <https://console.us.code42.com/swagger/#/role/Role_View>`__
+
+        Returns:
+            :class:`py42.response.Py42Response`
+        """
+        uri = u"/api/v4/role/view"
+        return self._session.get(uri)
+
+    def get_roles(self, user_id):
+        """Return the list of roles that are currently assigned to the given user.
+        `REST Documentation <https://console.us.code42.com/apidocviewer/#UserRole-get>`__
+
+        Args:
+            user_id (int): An ID for a user.
+
+        Returns:
+            :class:`py42.response.Py42Response`
+        """
+        uri = u"/api/UserRole/{}".format(user_id)
+        return self._session.get(uri)
+
+    def add_role(self, user_id, role_name):
+        """Adds a role to a user.
+        `REST Documentation <https://console.us.code42.com/apidocviewer/#UserRole-post>`__
+
+        Args:
+            user_id (int): An ID for a user.
+            role_name (str): The name of the role to assign to the user.
+
+        Returns:
+            :class:`py42.response.Py42Response`
+        """
+        uri = u"/api/UserRole"
+        data = {u"userId": user_id, u"roleName": role_name}
+        return self._session.post(uri, data=json.dumps(data))
+
+    def remove_role(self, user_id, role_name):
+        """Removes a role from a user.
+        REST Documentation <https://console.us.code42.com/apidocviewer/#UserRole-delete>`__
+
+        Args:
+            user_id (int): An ID for a user.
+            role_name (str): The name of the role to unassign from the user.
+
+        Returns:
+            :class:`py42.response.Py42Response`
+        """
+
+        # use quote instead of params here so that %20 is used instead of + for spaces.
+        role_name = quote(role_name)
+        uri = u"/api/UserRole?userId={}&roleName={}".format(user_id, role_name)
+        return self._session.delete(uri)
