@@ -14,9 +14,7 @@ class BaseQuery(object):
 
     @classmethod
     def from_dict(cls, _dict, group_clause=u"AND"):
-        filter_groups = [
-            FilterGroup.from_dict(item, item[u"filterClause"]) for item in _dict[u"groups"]
-        ]
+        filter_groups = [FilterGroup.from_dict(item) for item in _dict[u"groups"]]
         return cls(*filter_groups, group_clause=group_clause)
 
     @classmethod
