@@ -1,9 +1,7 @@
-from py42.sdk.queries.query_filter import (
-    QueryFilterStringField,
-    QueryFilterTimestampField,
-    create_filter_group,
-    create_query_filter,
-)
+from py42.sdk.queries.query_filter import create_filter_group
+from py42.sdk.queries.query_filter import create_query_filter
+from py42.sdk.queries.query_filter import QueryFilterStringField
+from py42.sdk.queries.query_filter import QueryFilterTimestampField
 
 
 def create_contains_filter_group(term, value):
