@@ -1,7 +1,5 @@
-from py42.sdk.queries.fileevents.file_event_query import (
-    FileEventFilterComparableField,
-    FileEventFilterStringField,
-)
+from py42.sdk.queries.fileevents.file_event_query import FileEventFilterComparableField
+from py42.sdk.queries.fileevents.file_event_query import FileEventFilterStringField
 from py42.sdk.queries.query_filter import QueryFilterStringField
 
 
