@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
-
+from collections import OrderedDict
 from datetime import datetime
 
 from py42._internal.compat import str
-from py42.util import convert_datetime_to_timestamp_str, convert_timestamp_to_str
+from py42._internal.compat import string_type
+from py42.util import convert_datetime_to_timestamp_str
+from py42.util import convert_timestamp_to_str
 
 
 def create_query_filter(term, operator, value=None):
@@ -126,7 +128,9 @@ class QueryFilterTimestampField(object):
         """
         formatted_start_time = convert_timestamp_to_str(start_value)
         formatted_end_time = convert_timestamp_to_str(end_value)
-        return create_in_range_filter_group(cls._term, formatted_start_time, formatted_end_time)
+        return create_in_range_filter_group(
+            cls._term, formatted_start_time, formatted_end_time
+        )
 
     @classmethod
     def on_same_day(cls, value):
@@ -142,7 +146,9 @@ class QueryFilterTimestampField(object):
         )
         formatted_start_time = convert_datetime_to_timestamp_str(start_time)
         formatted_end_time = convert_datetime_to_timestamp_str(end_time)
-        return create_in_range_filter_group(cls._term, formatted_start_time, formatted_end_time)
+        return create_in_range_filter_group(
+            cls._term, formatted_start_time, formatted_end_time
+        )
 
 
 class QueryFilterBooleanField(object):
@@ -197,16 +203,30 @@ class QueryFilter(object):
         return self._value
 
     def __str__(self):
-        value = u"null" if self._value is None else u'"{0}"'.format(self._value)
+        value = u"null" if self._value is None else u'"{}"'.format(self._value)
         return u'{{"operator":"{0}", "term":"{1}", "value":{2}}}'.format(
             self._operator, self._term, value
         )
 
     def __iter__(self):
-        output_dict = {u"operator": self._operator, u"term": self._term, u"value": self._value}
+        output_dict = OrderedDict()
+        output_dict[u"operator"] = self._operator
+        output_dict[u"term"] = self._term
+        output_dict[u"value"] = self._value
         for key in output_dict:
             yield (key, output_dict[key])
 
+    def __eq__(self, other):
+        if isinstance(other, (QueryFilter, tuple, list)):
+            return tuple(self) == tuple(other)
+        elif isinstance(other, string_type):
+            return str(self) == other
+        else:
+            return False
+
+    def __hash__(self):
+        return hash(str(self))
+
 
 class FilterGroup(object):
     """Class for constructing a logical sub-group of related filters from a list of QueryFilter
@@ -226,9 +246,9 @@ class FilterGroup(object):
         self._filter_clause = filter_clause
 
     @classmethod
-    def from_dict(cls, _dict, filter_clause=u"AND"):
+    def from_dict(cls, _dict):
         filter_list = [QueryFilter.from_dict(item) for item in _dict[u"filters"]]
-        return cls(filter_list, filter_clause=filter_clause)
+        return cls(filter_list, filter_clause=_dict[u"filterClause"])
 
     @property
     def filter_list(self):
@@ -238,14 +258,38 @@ class FilterGroup(object):
     def filter_clause(self):
         return self._filter_clause
 
+    @filter_clause.setter
+    def filter_clause(self, value):
+        self._filter_clause = value
+
+    @property
+    def _filter_set(self):
+        return sorted(list(set(self.filter_list)), key=str)
+
     def __str__(self):
-        filters_string = u",".join(str(filter_item) for filter_item in self._filter_list)
+        filters_string = u",".join(str(filter_item) for filter_item in self._filter_set)
         return u'{{"filterClause":"{0}", "filters":[{1}]}}'.format(
             self._filter_clause, filters_string
         )
 
     def __iter__(self):
-        filter_list = [dict(item) for item in self._filter_list]
+        filter_list = [dict(item) for item in self._filter_set]
         output_dict = {u"filterClause": self._filter_clause, u"filters": filter_list}
         for key in output_dict:
             yield (key, output_dict[key])
+
+    def __eq__(self, other):
+        if isinstance(other, FilterGroup):
+            return (
+                self.filter_clause == other.filter_clause
+                and self._filter_set == other._filter_set
+            )
+        elif isinstance(other, (tuple, list)):
+            return tuple(self) == tuple(other)
+        elif isinstance(other, string_type):
+            return str(self) == other
+        else:
+            return False
+
+    def __contains__(self, item):
+        return item in self._filter_set
